@@ -504,11 +504,11 @@ use vars qw(@ISA @images);
 
 sub profile_default
 {
-	my %sup = %{$_[ 0]-> SUPER::profile_default};
+	my $sup = $_[ 0]-> SUPER::profile_default;
 	return {
-		%sup,
+		%$sup,
 		style            => cs::DropDownList,
-		height           => $sup{ editHeight},
+		height           => $sup->{editHeight},
 		firstDrive       => 'A:',
 		drive            => 'C:',
 		editClass        => 'Prima::DriveComboBox::InputLine',
@@ -978,6 +978,7 @@ sub init
 		text        => '~Help',
 		size        => [ 96, 36],
 		growMode    => gm::GrowLoX | gm::GrowLoY,
+		delegations => [qw(Click)],
 	) if $self-> {showHelp};
 
 	$self-> Name-> current(1);
@@ -1437,7 +1438,7 @@ sub Open_Click
 		}
 		if ( !$self-> {openMode} && !$self-> {noTestFileCreate}) {
 			my $file;
-			if ( open $file, ">>$_") {
+			if ( open $file, ">>", $_) {
 				close $file;
 			} else {
 				Prima::MsgBox::message_box( $self-> text, "Cannot create file $_: $!", mb::OK | mb::Error);
@@ -1452,6 +1453,8 @@ sub Open_Click
 	$self-> ok;
 }
 
+sub Help_Click { shift->help }
+
 sub filter
 {
 	if ( $#_) {
@@ -1662,6 +1665,7 @@ sub init
 		name        => 'Help',
 		text        => '~Help',
 		size        => [ 80, 30],
+		delegations => [qw(Click)],
 	) if $self-> {showHelp};
 
 	$self-> {curpaths} = {};
@@ -1717,6 +1721,8 @@ sub OK_Click
 	$self-> ok;
 }
 
+sub Help_Click { shift->help }
+
 sub directory
 {
 	return $_[0]-> Dir-> path unless $#_;
@@ -1978,6 +1984,8 @@ Default value: 0
 =item showHelp BOOLEAN
 
 A create-only property. If 1, the 'Help' button is inserted in the dialog.
+When pressed, opens a help section stored in the C<helpContext> property.
+See L<Prima::Widget/help>, L<Prima::Widget/helpContext>
 
 Default value: 0
 
