@@ -86,7 +86,7 @@ sub size
 
 	my $em = $self->em;
 	my $icon_width = 0;
-	if ( my $icon = $self-> icon ) {
+	if ( $self->vertical && (my $icon = $self-> icon )) {
 		my @asz = map { $_ / 4 } $::application-> size;
 		$icon_width = $icon-> width;
 		$icon_width = $asz[0] if $icon_width > $asz[0];
@@ -94,6 +94,7 @@ sub size
 		my $h = $icon-> height;
 		$h = $asz[1] if $h > $asz[1];
 		$sz[1] = $h if $sz[1] < $h;
+		$icon_width += $em;
 	} else {
 		$icon_width = 2 * $em # space for *
 			if $self->vertical || $self->checked || $self->autoToggle;
@@ -242,11 +243,11 @@ sub draw
 	my $em = $self-> em;
 	my $y_offset = $self-> y_offset;
 
-	my ($draw_check, $draw_accel, $draw_submenu, $draw_check_aa);
+	my ($draw_check, $draw_accel, $draw_submenu, $draw_check_aa, $draw_radio);
 
 	my $lw = 3;
-	if ( my $icon = $self-> icon ) {
-		$self-> draw_bitmap( $owner, $canvas, $colors, $icon, $x + 2, $y + $y_offset, $self->{icon_width}, $h - $y_offset * 2 );
+	if ( $vertical && (my $icon = $self-> icon )) {
+		$self-> draw_bitmap( $owner, $canvas, $colors, $icon, $x + 2, $y + $y_offset, $self->{icon_width} - $em, $h - $y_offset * 2 );
 	} elsif ( $checked ) {
 		my $font = $canvas->font;
 		my $Dx = $em * 0.25;
@@ -257,14 +258,22 @@ sub draw
 		$Xw = 3 if $Xw < 3;
 		$Xw /= 2;
 		$Y -= $Xw;
-		$draw_check    = [$X, $Y, $X + $Dx, $Y - $Dy, $X + $Dx * 3, $Y + $Dy];
-		$draw_check_aa = [
-			$X - $Xw, $Y,
-			$X + $Dx, $Y - $Dy - $Xw,
-			$X + $Dx * 3 + $lw, $Y + $Dy,
-			$X + $Dx, $Y - $Dy + $Xw,
-			$X, $Y - $Xw,
-		];
+		if ( $self->group > 0 ) {
+			my $D = $em / 2;
+			$Y -= $D / 2;
+			$draw_radio =  [
+				$X, $Y, $X + $D, $Y + $D, $X + $D * 2, $Y, $X + $D, $Y - $D
+			];
+		} else {
+			$draw_check    = [$X, $Y, $X + $Dx, $Y - $Dy, $X + $Dx * 3, $Y + $Dy];
+			$draw_check_aa = [
+				$X - $Xw, $Y,
+				$X + $Dx, $Y - $Dy - $Xw,
+				$X + $Dx * 3 + $lw, $Y + $Dy,
+				$X + $Dx, $Y - $Dy + $Xw,
+				$X, $Y - $Xw,
+			];
+		}
 	} elsif ( $autotoggle ) {
 		my $Y  = $y + $h / 2;
 		my $D  = $em * 0.5;
@@ -293,7 +302,7 @@ sub draw
 	$h -= $y_offset * 2;
 	if ( $self->{accel_width} > 0 ) {
 		my $X = $x + $w - $self->{accel_width} - $em * ( $vertical ? 1.5 : 0.5 );
-		$draw_accel = [ $self->accel, $X, $y ];
+		$draw_accel = [ $self->accel, $X, $y + ( $h - $canvas-> font-> height ) / 2 ];
 		$w -= $self-> {accel_width} + $em * 0.5;
 	}
 
@@ -305,9 +314,9 @@ sub draw
 	}
 	$w -= $em * ($vertical ? 1.5 : 0.5 );
 
-	if ( $draw_check || $draw_accel || $draw_submenu ) {
+	if ( $draw_check || $draw_accel || $draw_submenu || $draw_radio ) {
 		return unless $canvas->graphic_context_push;
-		$canvas->antialias(1) if $draw_check || $draw_submenu;
+		$canvas->antialias(1) if $draw_check || $draw_radio || $draw_submenu;
 		if ($draw_check) {
 			unless ( $canvas-> antialias ) {
 				$canvas->lineWidth($lw);
@@ -324,6 +333,8 @@ sub draw
 				} else {
 					$canvas->polyline($draw_check);
 				}
+			} elsif ( $draw_radio ) {
+				$canvas->fillpoly($draw_radio);
 			}
 			$canvas->text_out( @$draw_accel) if $draw_accel;
 			$canvas->fillpoly($draw_submenu) if $draw_submenu;
@@ -338,6 +349,8 @@ sub draw
 			} else {
 				$canvas->polyline($draw_check);
 			}
+		} elsif ( $draw_radio ) {
+			$canvas->fillpoly($draw_radio);
 		}
 		$canvas->text_out( @$draw_accel ) if $draw_accel;
 		$canvas->fillpoly($draw_submenu)  if $draw_submenu;
@@ -475,8 +488,8 @@ sub _export_constants
 {
 my %RNT = (
 	%{Prima::Widget-> notification_types()},
-	Submenu      => nt::Default,
-	ItemChanged  => nt::Default,
+	MenuSelect  => nt::Default,
+	Menu        => nt::Default,
 );
 
 sub notification_types { return \%RNT; }
@@ -599,6 +612,9 @@ sub selectedItem
 	$self->{selectedItem} = $i;
 	$self->invalidate_rect( $self->get_item_rect($old) ) if $old >= 0;
 	$self->invalidate_rect( $self->get_item_rect($i) )   if $i   >= 0;
+	if ( defined ( my $itemid = $self->{cache}->[$i]->[ITEMID] )) {
+		$self->root->notify(qw(MenuSelect), $itemid);
+	}
 }
 
 sub enter_submenu
@@ -623,7 +639,7 @@ sub enter_submenu
 		$index  = $self-> parentIndex + @{ $self->{cache} } - 1;
 	}
 
-	$self->notify(qw(Submenu), $i);
+	$self->root->notify(qw(Menu), $itemid);
 	return unless $self->alive;
 
 	$self->{submenu_index} = $i;
@@ -1130,6 +1146,7 @@ sub cancel
 {
 	my $self = shift;
 	my $s = $self->{submenu};
+	my $os = $s;
 	while ( $s ) {
 		my $ss = $s->{submenu};
 		$s->destroy;
@@ -1137,7 +1154,7 @@ sub cancel
 	}
 	$self->{submenu} = undef;
 	$self->{selectedItem} = -1;
-	$self-> notify(q(MenuLeave));
+	$self-> notify(q(MenuLeave)) if $os;
 	$self-> hide;
 }
 
@@ -1245,6 +1262,7 @@ sub cancel
 {
 	my $self = shift;
 	my $s = $self->{submenu};
+	my $os = $s;
 	while ( $s ) {
 		my $ss = $s->{submenu};
 		$s->destroy;
@@ -1255,7 +1273,7 @@ sub cancel
 	return unless $self->alive;
 	$self->focused(0);
 	$self->repaint;
-	$self-> notify(q(MenuLeave));
+	$self-> notify(q(MenuLeave)) if $os;
 }
 
 
@@ -1460,7 +1478,7 @@ widgets, without any special considerations about system-depended menus.
 		pack  => { fill => 'x', expand => 1},
 		menu  => $w-> accelTable,
 	);
-	run Prima;
+	Prima->run;
 
 =for podview <img src="Prima/menu.gif">
 
