@@ -1297,7 +1297,7 @@ Prima::TextView - rich text browser widget
  use warnings;
  use Prima qw(TextView Application);
 
- my $w = Prima::MainWindow-> create(
+ my $w = Prima::MainWindow-> new(
      name => 'TextView example',
  );
 
@@ -1325,7 +1325,7 @@ Prima::TextView - rich text browser widget
  # selection:
  $t->paneSize($text_width_px, $font_height_px);
 
- run Prima;
+ Prima->run;
 
 =for podview <img src="textview.gif">
 
