@@ -6,13 +6,12 @@ examples/buttons.pl - Prima button widgets
 
 =head1 FEATURES
 
-Demonstrates basic use of Prima toolkit, in particular
-creation of built-in push-buttons and radio-buttons. L<Prima::Buttons>
-A customized button creation with subclassing is exemplified
+Demonstrates basic use of Prima toolkit:
+creation of built-in push-buttons, radio-buttons, and
+a customized subclassed button
 
 =cut
 
-
 use strict;
 use warnings;
 
@@ -64,32 +63,6 @@ sub on_paint
 	}
 }
 
-sub clone
-{
-	my ( $self, %profile) = @_;
-	my %d = %{$self-> profile_default};
-	my %readfilter = (
-		x_centered  => 1,
-		y_centered  => 1,
-		centered    => 1,
-		delegations => 1,
-		designScale => 1,
-	);
-	my %hashed = (
-		font      => 1,
-		popupFont => 1,
-		menuFont  => 1,
-	);
-	for ( keys %readfilter) { delete $d{$_}};
-	for ( keys %d) {
-		my @res = $self-> $_();
-		$d{$_} = @res ? ($#res ? (
-			$hashed{$_} ? {@res} : [@res]
-		) : $res[0]) : undef;
-	}
-	return ref($self)-> create( %d, %profile);
-}
-
 package main;
 
 sub set_style
@@ -98,7 +71,7 @@ sub set_style
 	$_[0]->repaint;
 }
 
-my $w = Prima::MainWindow-> create(
+my $w = Prima::MainWindow-> new(
 	text   => "Button example",
 	centered  => 1,
 	height    => 300,
@@ -106,8 +79,8 @@ my $w = Prima::MainWindow-> create(
 	designScale => [7, 16],
 	menuItems => [
 		['~Skin' => [
-			[ '(*default' => 'Default' => \&set_style ],
-			[ ')flat'     => 'Flat'    => \&set_style ],
+			[ '(classic'  => 'Classic 3D' => \&set_style ],
+			[ ')flat'     => 'Flat'       => \&set_style ],
 		]],
 	],
 );
@@ -122,10 +95,7 @@ my $l = $w->insert( "UserButton" , origin => [ 250,180], autoRepeat => 1);
 
 $w->insert( "Radio"      , origin => [  50,140]);
 
-my $metafile = Prima::Drawable::Metafile->new( size => [70, 70] );
-$metafile->begin_paint;
-$metafile->lineJoin(lj::Miter);
-$metafile->lineWidth(5);
+
 my $c = 3.14159 * 2 / 7;
 my @pts = map { 35 + int(25 * $_ + .5) } (
 	1,0,
@@ -138,16 +108,20 @@ my @pts = map { 35 + int(25 * $_ + .5) } (
 	1,0,
 );
 
-$metafile->polyline(\@pts);
+my $metafile = Prima::Drawable::Metafile->new( size => [70, 70] );
+$metafile->begin_paint;
+$metafile->antialias(1);
+$metafile->lineJoin(lj::Miter);
+$metafile->call( sub {
+	my ($self, $canvas) = @_;
+	my $f = $canvas->fader_current_value // 0;
+	$canvas->color(cl::blend( $canvas->map_color(cl::Fore), cl::Green, $f));
+	$canvas->lineWidth( 5 * ( 1 - $f) );
+	my $method = ( $f == 1 ) ? 'fillpoly' : 'polyline';
+	$canvas->$method(\@pts);
+});
 $metafile->end_paint;
 
-my $metafile2 = Prima::Drawable::Metafile->new( size => [25, 25] );
-$metafile2->begin_paint;
-$metafile2->color(cl::Green);
-$metafile2->fillWinding(fm::Winding);
-$metafile2->fillpoly(\@pts);
-$metafile2->end_paint;
-
 $w->insert(
 	"Button"     ,
 	origin => [ 50,50],
@@ -155,7 +129,6 @@ $w->insert(
 	image => $metafile,
 	text => '',
 	name => 'Meta',
-	hiliteGlyph => $metafile2,
 );
 
-run Prima;
+Prima->run;
