@@ -17,7 +17,7 @@ use warnings;
 
 use Prima qw(Buttons StdBitmap Application);
 
-my $w = Prima::MainWindow-> create(
+my $w = Prima::MainWindow-> new(
 	text=> "Handmade buttons",
 	size => [ 300, 200],
 	centered => 1,
@@ -82,7 +82,7 @@ $w-> insert( Button =>
 	onClick    => sub {
 		my $self = $_[0];
 		unless ( $self-> get_shift_state & km::Ctrl) {
-			my $i = Prima::Image-> create(
+			my $i = Prima::Image-> new(
 				width  => $self-> width,
 				height => $self-> height,
 				font   => $self-> font,
@@ -103,15 +103,17 @@ $w-> insert( Button =>
 	},
 );
 
-$w-> insert( SpeedButton =>
-	origin     => [ 250, 10],
+$w-> insert( PopupButton =>
+	origin     => [ 230, 10],
 	image      => $j,
 	glyphs     => 2,
 	text    => 0,
-	checkable  => 1,
 	holdGlyph  => 1,
-	hint       => 'C\'mon, press me!',
+	popupItems => [
+		['File' => sub {}],
+		['Edit' => sub {}],
+	],
 );
 
 
-run Prima;
+Prima->run;
