@@ -7,7 +7,7 @@ examples/calendar.pl - Standard calendar widget
 =head1 FEATURES
 
 Demonstrates usage of L<Prima::Calendar>.
-Note the special check of C<useLocale> success.
+Note the check of C<useLocale> success status.
 
 =cut
 
@@ -18,15 +18,15 @@ use Prima::Application name => 'Calendar';
 use Prima::Calendar;
 
 my $cal;
-my $w = new Prima::MainWindow(
+my $w = Prima::MainWindow->new(
 	text => "Calendar example",
-	size => [ 200, 200],
+	size => [ 500, 500],
 	designScale => [6,16],
 	menuItems => [[ "~Options" => [
-		[ 'locale', 'Use ~locale', 'Ctrl+L', '^L', sub {
-			my ( $self, $mid) = @_;
+		[ '@locale', 'Use ~locale', 'Ctrl+L', '^L', sub {
+			my ( $self, $mid, $val) = @_;
 			my $newstate;
-			$cal-> useLocale( $newstate = $self-> menu-> toggle( $mid));
+			$cal-> useLocale( $newstate = $val );
 			$cal-> notify(q(Change));
 			return unless $newstate && !$cal-> useLocale;
 			$self-> menu-> uncheck( $mid);
@@ -35,9 +35,9 @@ my $w = new Prima::MainWindow(
 		[ 'Re~set to current date', 'Ctrl+R', '^R', sub {
 			$cal-> date_from_time( localtime( time));
 		}],
-		[ 'monday', '~Monday is the first day of week', sub {
-			my ( $self, $mid) = @_;
-			$cal-> firstDayOfWeek( $self-> menu-> toggle( $mid) ? 1 : 0);
+		[ '@monday', '~Monday is the first day of week', sub {
+			my ( $self, $mid, $val) = @_;
+			$cal-> firstDayOfWeek( $val );
 		}],
 	]]],
 );
@@ -52,5 +52,5 @@ $cal = $w-> insert( Calendar =>
 
 $w-> menu-> locale-> check if $cal-> useLocale;
 
-run Prima;
+Prima->run;
 
