@@ -1,14 +1,26 @@
+=pod
+
+=head1 NAME
+
+examples/canvas.pl - custom canvas widget
+
+=head1 FEATURES
+
+An attempt to build a widget similar to Tk::Canvas
+
+=cut
+
 use strict;
 use warnings;
 
-use Prima qw(ScrollWidget);
+use Prima qw(Widget::ScrollWidget);
 # A widget with two scrollbars. Contains set of objects, that know
 # how to draw themselves. The graphic objects hierarchy starts
 # from Prima::CanvasObject:: class
 
 package Prima::Canvas;
 use vars qw(@ISA);
-@ISA = qw(Prima::ScrollWidget);
+@ISA = qw(Prima::Widget::ScrollWidget);
 
 sub profile_default
 {
@@ -69,6 +81,7 @@ sub on_paint
 		);
 		%props = map { $_ => 1 } @uses;
 
+		$canvas-> fillPatternOffset( @r[0,1] );
 		$canvas-> translate( @r[4,5]);
 		$canvas-> clipRect( @r[0..3]);
 		$obj-> on_paint( $canvas, $r[6]-$r[4], $r[7]-$r[5]);
@@ -1736,7 +1749,7 @@ $logo = Prima::StdBitmap::icon(0);
 $bitmap-> set( conversion => ict::None, type => im::BW);
 $bitmap = $bitmap-> bitmap;
 
-my $w = Prima::MainWindow-> create(
+my $w = Prima::MainWindow-> new(
 text => 'Canvas demo',
 menuItems => [
 	['~Object' => [
@@ -1750,19 +1763,42 @@ menuItems => [
 		['backColor' => '~Background color' => \&set_color],
 		['alpha' => '~Alpha' => [ map { [ $_, $_, \&set_alpha ] } 0, 32, 64, 96, 128, 164, 192, 224, 255]],
 		[],
-		['~Line width' => [ map { [ "lw$_", $_, \&set_line_width ] } 0..7, 10, 15 ]],
+		['~Line width' => [ map { [ "lw$_", $_, \&set_line_width ] } 0, 0.25, 0.5, 0.75, 1..7, 10, 15, 20 ]],
 		['Line ~pattern' => [ map { [ "lp:linePattern=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %lp:: ]],
 		['Line ~end' => [ map { [ "le:lineEnd=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %le:: ]],
 		['Line ~join' => [ map { [ "lj:lineJoin=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %lj:: ]],
-		['Fill ~pattern' => [ map { [ "fp:fillPattern=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fp:: ]],
-		['~Rop' => [ map { [ "rop:rop=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %rop:: ]],
-		['Rop~2' => [ map { [ "rop:rop2=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %rop:: ]],
+		['Fill ~pattern' => [
+				[ Icon   => Icon   => \&set_fill_pattern ],
+				[ Bitmap => Bitmap => \&set_fill_pattern ],
+				[],
+				map { [ "fp:fillPattern=$_", $_, \&set_fill_pattern ] }
+					sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fp::
+		]],
+		['~Rop' => [ map { [ "rop:rop=$_", $_, \&set_constant ] } qw(
+				CopyPut
+				XorPut
+				AndPut
+				OrPut
+				NotPut
+				Invert
+				Blackness
+				NotDestAnd
+				NotDestOr
+				Whiteness
+				NotSrcAnd
+				NotSrcOr
+				NotXor
+				NotAnd
+				NotOr
+				NoOper
+		)]],
+		['Rop~2' => [ map { [ "rop:rop2=$_", $_, \&set_constant ] } qw(
+				CopyPut
+				NoOper
+		)]],
 		['Fill r~ule' => [ map { [ "fm:fillMode=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fm:: ]],
 		[],
@@ -1789,6 +1825,10 @@ menuItems => [
 				map {["arrow=$_", $_, \&set_arrowhead]} 1,2,3,4,5
 			]],
 		]],
+		['Filled shapes' => [
+			['fillBackColor'    => '~Fill back color' => \&set_color],
+			['outlineBackColor' => '~Outline back color' => \&set_color],
+		]],
 		['Te~xt' => [
 			['font' => '~Font' => \&set_font],
 			[],
@@ -1871,18 +1911,18 @@ sub insert
 		$profile{anchor} = [50,50];
 	}
 	if ( $obj eq 'Button') {
-		$profile{widget} = Prima::Button-> create( owner => $c);
+		$profile{widget} = Prima::Button-> new( owner => $c);
 		$obj = 'Widget';
 	}
 	if ( $obj eq 'InputLine') {
-		$profile{widget} = Prima::InputLine-> create( owner => $c);
+		$profile{widget} = Prima::InputLine-> new( owner => $c);
 		$profile{scalable} = 0;
 		$obj = 'Widget';
 	}
 	if ( $obj eq 'Widget') {
 		$profile{widget}-> popupItems( $widget_popup);
 	}
-	$profile{text} = "use Prima qw(Application);\nMainWindow-> create();\nrun Prima;"
+	$profile{text} = "use Prima qw(Application);\nMainWindow-> new();\nPrima->run;"
 		if $obj eq 'Text';
 	$c-> focused_object( $c-> insert_object( "Prima::Canvas::$obj", %profile));
 }
@@ -1913,7 +1953,8 @@ sub set_color
 	my ( $self, $property) = @_;
 	my $obj;
 	return unless $obj = $self-> Canvas-> focused_object;
-	$colordialog = Prima::Dialog::ColorDialog-> create unless $colordialog;
+	return unless $obj->can($property);
+	$colordialog = Prima::Dialog::ColorDialog-> new unless $colordialog;
 	$colordialog-> value( $obj-> $property());
 	$obj-> $property( $colordialog-> value) if $colordialog-> execute != mb::Cancel;
 }
@@ -1923,11 +1964,27 @@ sub set_font
 	my ( $self, $property) = @_;
 	my $obj;
 	return unless $obj = $self-> Canvas-> focused_object;
-	$fontdialog = Prima::Dialog::FontDialog-> create unless $fontdialog;
+	$fontdialog = Prima::Dialog::FontDialog-> new unless $fontdialog;
 	$fontdialog-> logFont( $obj-> font);
 	$obj-> font( $fontdialog-> logFont) if $fontdialog-> execute != mb::Cancel;
 }
 
+sub set_fill_pattern
+{
+	my ( $self, $fp) = @_;
+	my $obj;
+	return unless $obj = $self-> Canvas-> focused_object;
+
+	if ( $fp eq 'Icon') {
+		$obj-> fillPattern($logo);
+	} elsif ( $fp eq 'Bitmap') {
+		$obj-> fillPattern($bitmap->image);
+	} else {
+		return unless $fp =~ /^(\w+)\:(\w+)\=(.*)$/;
+		$obj-> $2( eval "$1::$3");
+	}
+}
+
 sub set_line_width
 {
 	my ( $self, $lw) = @_;
@@ -2071,9 +2128,9 @@ sub set_text_flags
 }
 
 insert( $c, 'Button', origin => [ 0, 0]);
-insert( $c, 'Rectangle', linePattern => lp::DotDot, lineWidth => 10, origin => [ 50, 50]);
+insert( $c, 'Rectangle', linePattern => lp::DotDot, lineWidth => 10, origin => [ 50, 50], fillPattern => $logo);
 insert( $c, 'Line', origin => [ 200, 200], antialias => 1);
 insert( $c, 'Polygon', origin => [ 150, 150]);
 insert( $c, 'Bitmap', origin => [ 350, 350], backColor => cl::LightGreen, color => cl::Green);
 
-run Prima;
+Prima->run;
