@@ -6,9 +6,9 @@ examples/cv.pl - Standard color dialog
 
 =head1 FEATURES
 
-Demonstrates usage of a standard color dialog.
+Demonstrates usage of the standard color dialog.
 Note the left-button drag effect from the color wheel with
-compbinations of Shift,Alt,and Control.
+combinations of Shift,Alt,and Control keys.
 
 =cut
 
@@ -16,7 +16,7 @@ use strict;
 use warnings;
 use Prima 'Dialog::ColorDialog', 'Application';
 
-my $p = Prima::Dialog::ColorDialog-> create(
+my $p = Prima::Dialog::ColorDialog-> new(
 	value => 0x3030F0,
 	visible => 1,
 	quality => 1,
