@@ -2,24 +2,24 @@
 
 =head1 NAME
 
-examples/drivecombo.pl - File tree widgets
+examples/drivecombo.pl - file tree widgets
 
 =head1 FEATURES
 
-Use of standard file-listbox and drive-combo box ( the latter
-is idle under *nix )
+Use of standard file-listbox and drive-combo box (the latter though is useless under
+unix)
 
 =cut
 
 use strict;
 use warnings;
 use Prima::ComboBox;
-use Prima::FileDialog;
+use Prima::Dialog::FileDialog;
 
 package UserInit;
-$::application = Prima::Application-> create( name => "DriveCombo");
+$::application = Prima::Application-> new( name => "DriveCombo");
 
-my $w = Prima::MainWindow-> create(
+my $w = Prima::MainWindow-> new(
 	text   => "Combo box",
 	left   => 100,
 	bottom => 300,
@@ -37,4 +37,4 @@ $w-> insert( DirectoryListBox =>
 	onChange => sub { print $_[0]-> path."\n"},
 );
 
-run Prima;
+Prima->run;
