@@ -1,15 +1,14 @@
-=pod 
+=pod
 
 =head1 NAME
 
-examples/ownerchange.pl - A recreate functionality example.
+examples/ownerchange.pl - implicit re-creation of widgets
 
 =head1 FEATURES
 
-Widgets that change owner dynamically often gets 
-recreated internally - one system window gets
-destroyed and another created then. Test the correct
-implementation of Prima owner change functionality.
+Widgets that dynamically change owners are re-created internally - a system
+window gets destroyed and another created thereafter. The example tests the
+correct implementation of the owner-changing functionality
 
 =cut
 
@@ -17,7 +16,7 @@ use strict;
 use warnings;
 use Prima qw(Buttons Application);
 
-my $w = Prima::Window-> create(
+my $w = Prima::Window-> new(
 	name       => "D1",
 	text    => "Window Number One",
 	origin     =>  [ 100, 300],
@@ -34,7 +33,7 @@ my $w = Prima::Window-> create(
 	},
 );
 
-my $w2 = Prima::Window-> create(
+my $w2 = Prima::Window-> new(
 	name      => "D2",
 	text   => "Window Number Two",
 	designScale => [7, 16],
@@ -42,8 +41,8 @@ my $w2 = Prima::Window-> create(
 	size      =>  [ 450, 200],
 	font      => { name=>"System VIO",size=>18},
 	backColor => cl::Yellow,
-	onTimer   => sub { 
-		$_[0]-> backColor(($_[0]-> backColor == cl::Yellow) ? 
+	onTimer   => sub {
+		$_[0]-> backColor(($_[0]-> backColor == cl::Yellow) ?
 			cl::White : cl::Yellow)
 	},
 );
@@ -66,7 +65,7 @@ $w-> insert( Button =>
 	text  => "Change owner",
 	onClick  => sub {
 		my $oldOwner = $_[0]-> owner;
-		$_[0]-> owner (( $_[0]-> owner-> name eq "D1") ? 
+		$_[0]-> owner (( $_[0]-> owner-> name eq "D1") ?
 			$::application-> D2 : $::application-> D1);
 		my $timer = $::application-> Timer1;
 		if ( $timer-> {win} == $w)
@@ -88,4 +87,4 @@ $::application-> insert( Timer =>
 	},
 );
 
-run Prima;
+Prima->run;
