@@ -1,12 +1,12 @@
-=pod 
+=pod
 
 =head1 NAME
 
-examples/pointers.pl - Prima mouse pointer example
+examples/pointers.pl - mouse pointer example
 
 =head1 FEATURES
 
-Demonstrates the usage of Prima mouse pointer functionality.
+Demonstrates the usage of the mouse pointer functionality.
 Note the custom pointer creation and its dynamic change ( the "User" button ).
 
 =cut
@@ -18,8 +18,10 @@ use Prima qw( StdBitmap Buttons Application);
 package UserInit;
 
 my $ph = Prima::Application-> get_system_value(sv::YPointer);
-my $w = Prima::MainWindow-> create(
-	size    => [ 350, 20 + ($ph+8)*11],
+my $sc = $::application-> uiScaling;
+$ph = $::application->font->height * 2 if $ph < $::application->font->height * 2;
+my $w = Prima::MainWindow-> new(
+	size    => [ 350 * $sc, 20 + ($ph+8)*15],
 	left    => 200,
 	text    => 'Pointers',
 );
@@ -38,12 +40,12 @@ my $i = 1;
 
 for my $c ( @a[0..$#a-1])
 {
-	my $p = eval("cr::$c"); 
+	my $p = eval("cr::$c");
 	$w-> pointer( $p);
 	my $b = $w-> insert( Button =>
 		flat => 1,
-		left    => 10 + (($i-1) % 2)*170,
-		width   => 160,
+		left    => (10 + (($i-1) % 2)*170) * $sc,
+		width   => 160 * $sc,
 		height  => $ph + 4,
 		bottom  => $w-> height - int(($i+1)/2) * ($ph+8) - 10,
 		pointer => $p,
@@ -54,29 +56,37 @@ for my $c ( @a[0..$#a-1])
 	$i++;
 };
 
-my $ptr = Prima::StdBitmap::icon( sbmp::DriveCDROM);
+my $ptr = Prima::StdBitmap::icon( sbmp::DriveCDROM, argb => 0, copy => 1);
+my $color_pointer = $::application->get_system_value(sv::ColorPointer);
 
 my @mapset = map {
-	my ($x,$a) = $ptr-> split;
-	my $j = Prima::Icon-> create;
+	my ($x,$r) = $ptr-> split;
+	my $j = Prima::Icon-> new;
 	$x-> begin_paint;
-	$x-> text_out( $_, 3, 3); 
+	$x-> text_out( $_, 3, 3);
 	$x-> end_paint;
-	$a-> begin_paint;
-	$a-> text_out( $_, 3, 3); 
-	$a-> end_paint;
-	$j-> combine( $x, $a);
+	$r-> begin_paint;
+	$r-> text_out( $_, 3, 3);
+	$r-> end_paint;
+	if ( $color_pointer ) { # add alpha
+		$r-> type(im::Byte);
+		$r-> rop2(rop::CopyPut);
+		$r->color(0xc0c0c0);
+		$r->backColor(0);
+		$r->map(0);
+	}
+	$j-> combine( $x, $r);
 	$j;
-} 1..4;   
+} 1..4;
 my $mapsetID = 0;
 
 my $b = $w-> insert( SpeedButton =>
-	left    => 10 + (($i-1) % 2)*170,
-	width   => 160,
+	left    => $sc * ( 10 + (($i-1) % 2)*170 ),
+	width   => 160 * $sc,
 	height  => $ph+4,
 	bottom  => $w-> height - int(($i+1)/2) * ($ph+8) - 10,
-	pointer => $ptr,
-	image   => $ptr,
+	pointer => $mapset[-1],
+	image   => $mapset[-1],
 	text => $a[-1],
 	flat => 1,
 	onClick => sub {
@@ -84,17 +94,17 @@ my $b = $w-> insert( SpeedButton =>
 	},
 );
 
-$b-> insert( Timer => 
-	timeout => 1250, 
+$b-> insert( Timer =>
+	timeout => 1250,
 	onTick  => sub {
 		$b-> pointerIcon( $mapset[$mapsetID]);
 		$b-> image( $mapset[$mapsetID]);
 		$mapsetID++;
 		$mapsetID = 0 if $mapsetID >= @mapset;
-	},   
+	},
 )-> start;
 
 $w-> pointer( cr::Default);
 $::application-> pointerVisible(1);
 
-run Prima;
+Prima->run;
