@@ -21,7 +21,7 @@ my $loop = AnyEvent->condvar;
 my $impl = AnyEvent::detect;
 print "AnyEvent implementation is $impl\n";
 
-my $w = Prima::MainWindow-> create(
+my $w = Prima::MainWindow-> new(
 	size      => [ $::application-> width * 0.6, $::application-> height * 0.6],
 	text      => 'AnyEvent demo',
 	onDestroy => sub {
@@ -85,7 +85,7 @@ my $il = $w-> insert( InputLine =>
 );
 $il-> select_all;
 
-# replace 'run Prima' with the below timer
+# replace 'Prima->run' with the below timer
 my $timer = AnyEvent->timer(after => 0, interval => 1/100, cb => sub {
         $::application->yield;
 });
