@@ -38,6 +38,9 @@
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_OUTLINE_H
+#ifdef FT_COLOR_H
+#include FT_COLOR_H
+#endif
 #endif
 #if defined(WITH_FONTCONFIG)
 #include <fontconfig/fontconfig.h>
@@ -66,7 +69,7 @@
 #endif
 
 #ifdef WITH_FRIBIDI
-#include <fribidi/fribidi.h>
+#include <fribidi.h>
 #define ANALYSIS FriBidiLevel
 #else
 #define ANALYSIS Byte
@@ -847,7 +850,7 @@ extern UnixGuts  guts;
 extern UnixGuts* pguts;
 
 #define XCHECKPOINT						\
-	{							\
+	if ( DISP ) {							\
 		pguts-> ri[ pguts-> ri_head]. line = __LINE__;			\
 		pguts-> ri[ pguts-> ri_head]. file = __FILE__;			\
 		pguts-> ri[ pguts-> ri_head]. request = NextRequest(DISP);	\
@@ -1661,7 +1664,7 @@ extern Byte*
 prima_xft_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance, int *bpp);
 
 extern Bool
-prima_xft_is_font_colored(Handle self);
+prima_xft_font_has_color(Handle self);
 
 #endif
 
@@ -1944,13 +1947,13 @@ Bool
 prima_ft_combining_supported( FT_Face face );
 
 extern int
-prima_ft_get_glyph_outline( FT_Face face, FT_UInt ft_index, FT_Int32 ft_flags, int ** buffer);
+prima_ft_get_glyph_outline( FT_Face face, FT_UInt ft_index, FT_Int32 ft_flags, Bool want_color, int ** buffer);
 
 extern Byte*
 prima_ft_get_glyph_bitmap( FT_Face face, FT_UInt index, FT_Int32 flags, PPoint offset, PPoint size, int *advance, int *bpp);
 
 extern Bool
-prima_ft_is_font_colored( FT_Face face);
+prima_ft_font_has_color( FT_Face face);
 
 extern Bool
 prima_ft_text_shaper_harfbuzz( FT_Face face, PTextShapeRec r);
