@@ -247,7 +247,7 @@ run_screenshot_app(void)
 	while (1) {
 		int n = read( s, buf, sizeof(int) * 4 );
 		if ( n < sizeof(int) * 4 ) {
-			Mdebug("bad screenshot request");
+			Mdebug("screenshot: bad screenshot request");
 			break;
 		}
 		buf[0] = make_screenshot(buf[0], buf[1], buf[2], buf[3]);
@@ -317,6 +317,7 @@ prima_gtk_init(void)
 	if ( socketpair(AF_UNIX, SOCK_STREAM, PF_UNSPEC, gtk_screenshot_sockets) == 0) {
 		gtk_screenshot_pid  = fork();
 		if ( gtk_screenshot_pid == 0 ) {
+			(void) setsid();
 			close(gtk_screenshot_sockets[0]);
 			run_screenshot_app();
 			exit(0);
