@@ -30,7 +30,7 @@ apc_gp_done( Handle self)
 {
 	objCheck false;
 	cleanup_gc_stack(self, 1);
-	aa_free_arena(self, 0);
+	text_aa_free_arena(self, 0);
 	if ( sys bm)
 		if ( !DeleteObject( sys bm)) apiErr;
 	if ( sys pal)
